clear
close all

Pre = 1e-3;
Rb=[1e6, 20e6:20e6:200e6];  % Values of the bitrate %bit rate Rb=1/Tb, Tb is duration of a bit
MOD = [1 2] ; % 1 PAM - 2 PPM
M   = [2 4 8]; %Modulation order
Gt = 1; Gr=1; %Antenna gains
F_dB = 7; %Noise figure [dB]
M_dB = 5; %System Margin [dB]
Amax = 10^(-13.15); %[W/Hz]
n = 5;
sigma = 51e-12;%[s]


%5th derivative of Gaussian pulse
f = linspace (1, 30e9, 2^11);
[PSD] = gaussian_PSD_nth(f, n,sigma, Amax);
%FCC_mask
FCC_mask=FCC_outdoor_mask(f);

plot(f,10*log10(PSD*1e3)+60,'b-','LineWidth',1.5)
hold on
plot(f,FCC_mask,'r-','LineWidth',2)
set(gca,'FontSize',12)
xlim([1 15e9])
ylim([-80 -40])
xlabel('Frequency [Hz]')
ylabel('PSD [dBm/MHz]')

%Truncated PSD of Gaussian derivative
[f_th_dB,PSD_th_dB] = truncated_thr_dB_vectors(f,PSD,-3);
totalPower=sum(PSD_th_dB)*(f_th_dB(end)-f_th_dB(1))/length(f_th_dB);
fprintf('Total power with 5th derivative: %1.3f mW\n',totalPower*1e3)

%Mask in the 3.1-10.6 GHz band
f=linspace(3.1e9,10.6e9,2^11);
PSD_mask=10.^(-41.3/10)*1e-3*1e-6*ones(1,length(f));
totalPower=sum(PSD_mask)*(f(end)-f(1))/length(f);
fprintf('Total power with FCC Mask: %1.3f mW\n',totalPower*1e3)

for j=1:length(MOD)
    for k=1:length(M)
        Eb_N0_min = getEbN0(MOD(j),M(k),Pre);
        for l=1:length(Rb)
            dist_Gaussian(j,k,l) = distcmpt(Eb_N0_min,Gt,Gr,M_dB,F_dB,Rb(l),PSD_th_dB,f_th_dB);
            dist_Mask(j,k,l) = distcmpt(Eb_N0_min,Gt,Gr,M_dB,F_dB,Rb(l),PSD_mask,f);
        end
    end
    if (MOD(j)==1)
        figure()
        dist_PAM_Gaussian=squeeze(dist_Gaussian(1,:,:));
        set(gcf,'DefaultAxesColorOrder',[0 0 0],'DefaultAxesLineStyleOrder','-+|-o|-*');
        
        PT = plot(Rb/1e6,dist_PAM_Gaussian);
        AX=gca;
        set(AX,'FontSize',12);
        X=xlabel('Data Rate [Mb/s]');
        set(X,'FontSize',14);
        Y=ylabel('Distance [m]');
        set(Y,'FontSize',14);
        L= legend('2-PAM','4-PAM','8-PAM');
        set(L,'FontSize',12);
        text(100,40,'Pr_e = 10^{-3}','BackgroundColor',[1 1 1],'FontSize',12);
        title ('PAM, 5th Derivatve of the Gaussian pulse')
        grid on
        
        dist_PAM_Mask=squeeze(dist_Mask(1,:,:));
        figure()
        set(gcf,'DefaultAxesColorOrder',[0 0 0],'DefaultAxesLineStyleOrder','-+|-o|-*');
        PT = plot(Rb/1e6,dist_PAM_Mask);
        AX=gca;
        set(AX,'FontSize',12);
        X=xlabel('Data Rate [Mb/s]');
        set(X,'FontSize',14);
        Y=ylabel('Distance [m]');
        set(Y,'FontSize',14);
        L= legend('2-PAM','4-PAM','8-PAM');
        set(L,'FontSize',12);
        text(100,40,'Pr_e = 10^{-3}','BackgroundColor',[1 1 1],'FontSize',12);
        title ('PAM, FCC mask')
        grid on
    else 
        figure()
        dist_PPM_Gaussian=squeeze(dist_Gaussian(2,:,:));
        set(gcf,'DefaultAxesColorOrder',[0 0 0],'DefaultAxesLineStyleOrder',':+|:o|:*');
        PT = plot(Rb/1e6,dist_PPM_Gaussian);
        AX=gca;
        set(AX,'FontSize',12);
        X=xlabel('Data Rate [Mb/s]');
        set(X,'FontSize',14);
        Y=ylabel('Distance [m]');
        set(Y,'FontSize',14);
        L= legend('2-PPM','4-PPM','8-PPM');
        set(L,'FontSize',12);
        text(100,40,'Pr_e = 10^{-3}','BackgroundColor',[1 1 1],'FontSize',12);
        title ('PPM, 5th Derivatve of the Gaussian pulse')
        grid on
        
        dist_PPM_Mask=squeeze(dist_Mask(2,:,:));
        figure()
        set(gcf,'DefaultAxesColorOrder',[0 0 0],'DefaultAxesLineStyleOrder',':+|:o|:*');
        PT = plot(Rb/1e6,dist_PPM_Mask);
        AX=gca;
        set(AX,'FontSize',12);
        X=xlabel('Data Rate [Mb/s]');
        set(X,'FontSize',14);
        Y=ylabel('Distance [m]');
        set(Y,'FontSize',14);
        L= legend('2-PPM','4-PPM','8-PPM');
        set(L,'FontSize',12);
        text(100,40,'Pr_e = 10^{-3}','BackgroundColor',[1 1 1],'FontSize',12);
        title ('PPM, FCC mask')
        grid on
    end
end
  
